@@ -47,8 +47,10 @@ int main(int argc,char **argv)
     else {
 	addr.sap_txtp.class = ATM_CBR;
 	addr.sap_txtp.min_pcr = atoi(argv[4]);
+	addr.sap_txtp.max_sdu = RFC1626_MTU;
     }
     addr.sap_rxtp.class = ATM_UBR;
+    addr.sap_rxtp.max_sdu = RFC1626_MTU;
     if (bind(s,(struct sockaddr *) &addr,sizeof(addr)) < 0) {
 	perror("bind");
 	return 1;
