@@ -256,7 +256,7 @@ int no_check = 0;
     
     host = argv[optind];
     if (atm) {
-	if (!strchr(host,'.') || strchr(strchr(host,'.')+1,'.')) {
+	if (!host || !strchr(host,'.') || strchr(strchr(host,'.')+1,'.')) {
 	    fprintf(stderr,"invalid ATM address (vpi.vci expected)\n");
 	    exit(1);
 	}
